#!/usr/bin/python
# -*- encoding=utf-8 -*-
from airflow import DAG
from datetime import datetime, timedelta
from airflow.contrib.hooks.ssh_hook import SSHHook
from airflow.contrib.operators.ssh_operator import SSHOperator
from airflow.sensors.external_task_sensor import ExternalTaskSensor
import json

from airflow.operators.email_operator import EmailOperator
from airflow.utils.trigger_rule import TriggerRule


sshHook = SSHHook(ssh_conn_id ='ssh_air')
default_args = {
'owner': 'info@idgvalue.com',
'email_on_failure': True,
'email_on_retry':True,
'start_date': datetime(2024, 1, 1),
'depends_on_past': False,
'retries': 6,
'retry_delay': timedelta(minutes=10),
}

dag = DAG('wf_dag_tk_api_1', default_args=default_args,
schedule_interval="5 0 * * *",
catchup=False,
dagrun_timeout=timedelta(minutes=160),
max_active_runs=3)

task_failed = EmailOperator (
    dag=dag,
    trigger_rule=TriggerRule.ONE_FAILED,
    task_id="task_failed",
    to=["info@idgvalue.com"],
    cc=[""],
    subject="tk_api_1_failed",
    html_content='<h3>您好，tk_api_1作业失败，请及时处理" </h3>')

update_scrm_contact_feign = SSHOperator(
ssh_hook=sshHook,
task_id='update_scrm_contact_feign',
command='python3 /data/airflow/etl/API/update_scrm_contact_feign.py',
depends_on_past=False, 
retries=3, 
dag=dag)

update_scrm_contact_load = SSHOperator(
ssh_hook=sshHook,
task_id='update_scrm_contact_load',
command='/data/airflow/etl/API/run_psql.sh {{ ds_nodash }} {{params.my_param }}',
params={'my_param':"update_scrm_contact_load"},
depends_on_past=False, 
retries=3, 
dag=dag)

update_scrm_contact_feign >> update_scrm_contact_load

scrm_contact_feign = SSHOperator(
ssh_hook=sshHook,
task_id='scrm_contact_feign',
command='python3 /data/airflow/etl/API/scrm_contact_feign.py',
depends_on_past=False, 
retries=3, 
dag=dag)

scrm_contact_load = SSHOperator(
ssh_hook=sshHook,
task_id='scrm_contact_load',
command='/data/airflow/etl/API/run_psql.sh {{ ds_nodash }} {{params.my_param }}',
params={'my_param':"scrm_contact_load"},
depends_on_past=False, 
retries=3, 
dag=dag)

scrm_contact_feign >> scrm_contact_load

custom_events_update_feign = SSHOperator(
ssh_hook=sshHook,
task_id='custom_events_update_feign',
command='python3 /data/airflow/etl/API/custom_events_update_feign.py',
depends_on_past=False, 
retries=3, 
dag=dag)

custom_events_update_load = SSHOperator(
ssh_hook=sshHook,
task_id='custom_events_update_load',
command='/data/airflow/etl/API/run_psql.sh {{ ds_nodash }} {{params.my_param }}',
params={'my_param':"custom_events_update_load"},
depends_on_past=False, 
retries=3, 
dag=dag)

custom_events_update_feign >> custom_events_update_load

scrm_contact_1129 = SSHOperator(
ssh_hook=sshHook,
task_id='scrm_contact_1129',
command='/data/airflow/etl/SA/run_sa.sh {{ ds_nodash }} {{ params.my_param }} >>/data/airflow/logs/run_psql_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"S98_S_scrm_contact"},
depends_on_past=False, 
retries=3, 
dag=dag)

scrm_contact_merge_6671 = SSHOperator(
ssh_hook=sshHook,
task_id='scrm_contact_merge_6671',
command='/data/airflow/etl/SA/run_sa.sh {{ ds_nodash }} {{ params.my_param }} >>/data/airflow/logs/run_psql_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"S98_S_scrm_contact_merge"},
depends_on_past=False, 
retries=3, 
dag=dag)

scrm_contact_lastupdated_4112 = SSHOperator(
ssh_hook=sshHook,
task_id='scrm_contact_lastupdated_4112',
command='/data/airflow/etl/SA/run_sa.sh {{ ds_nodash }} {{ params.my_param }} >>/data/airflow/logs/run_psql_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"S98_S_scrm_contact_lastupdated"},
depends_on_past=False, 
retries=3, 
dag=dag)

custom_events_update_load >> scrm_contact_merge_6671
update_scrm_contact_load >> scrm_contact_lastupdated_4112
scrm_contact_load >> scrm_contact_1129
scrm_contact_1129 >> task_failed 
