/***************************************************************************************************/
/*script in Sql, generate by SdmCreateScript 2020(by Qihang Feng, QF255001@TERADATA.COM)     */
/*VERSION 01.10 revised on 2020-08-25                                                              */
/*Brilliance stems from wisdoms.                                                                   */
/*************Head Section**************************************************************************/
/*Script Use: Periodically load data to :t00_country_info(国家信息)             */
/*Create Date:2024-01-16 18:27:51                                                                  */
/*SDM Developed By: dev                                                                            */
/*SDM Developed Date: 2024-01-16                                                                   */
/*SDM Checked By: dev                                                                              */
/*SDM Checked Date: 2024-01-16                                                                     */
/*Script Developed By: dev                                                                         */
/*Script Checked By: dev                                                                           */
/*Source table 1: p10_sa.s98_s_country_cde                                                         */
/*Job Type: Inbound transform (Tier 1 to Tier 2)                                                   */
/*Target Table:t00_country_info                                                                    */
/*ETL Job Name:t00_country_info                                                                    */
/*ETL Frequency:Daily                                                                              */
/*ETL Policy:F2                                                                                    */
/********************************************************************************************/
/*******Main Section**************************************************************************/
\set ON_ERROR_STOP on
\set AUTOCOMMIT on
\timing on



/*创建临时表加载当前数据                                                                           */
CREATE TEMPORARY TABLE t00_country_info_agi_CUR_I 
 ( LIKE :PDMDB.t00_country_info)
ON COMMIT PRESERVE ROWS;



/*创建临时表加载不同数据                                                                           */
CREATE TEMPORARY TABLE t00_country_info_agi_INS 
( LIKE :PDMDB.t00_country_info)
ON COMMIT PRESERVE ROWS;

            
/*****************************************************************************************************/
/* GROUP 1:Source Table:s98_s_country_cde*************************************************************/
/*****************************************************************************************************/
INSERT INTO t00_country_info_agi_CUR_I (
            country_cn_name                         /*国家*/
           ,country_en_name                         /*国家英文名*/
           ,country_cd                              /*国家代码*/
           ,country_abbr                            /*国家缩写*/
           ,country_number                          /*数字代码*/
           ,inter_tel_cd                            /*国际区号*/
           ,internet_name                           /*域名*/
           ,Etl_Batch_No                            /*作业批次号*/
           ,Etl_First_Dt                            /*最初入库时间*/
           ,Etl_Job                                 /*作业名称*/
           ,Etl_Proc_Dt                             /*本次入库时间*/
           ,Etl_Tx_Dt                               /*作业运行时间*/
           ,Src_Sysname                             /*来源系统*/
           ,Src_Table                               /*来源表*/
        )
SELECT
         COALESCE(TRIM(CAST(p0.country_cn_name AS varchar(50))),'')        /*country_cn_name*/
        ,COALESCE(TRIM(CAST(p0.country_en_name AS varchar(50))),'')        /*country_en_name*/
        ,COALESCE(TRIM(CAST(p0.country_cd AS varchar(10))),'')        /*country_cd*/
        ,COALESCE(TRIM(CAST(p0.country_abbr AS varchar(10))),'')        /*country_abbr*/
        ,COALESCE(CAST(p0.country_number AS int),0)                /*country_number*/
        ,COALESCE(TRIM(CAST(p0.inter_tel_cd AS varchar(10))),'')        /*inter_tel_cd*/
        ,COALESCE(TRIM(CAST(p0.internet_name AS varchar(20))),'')        /*internet_name*/
        ,0                                                         /*Etl_Batch_No*/
        ,TO_DATE(:TXDATE,'YYYYMMDD')                               /*Etl_First_Dt*/
        ,:ETLJOB                                                   /*Etl_Job*/
        ,current_timestamp(0)                                      /*Etl_Proc_Dt*/
        ,TO_DATE(:TXDATE,'YYYYMMDD')                               /*Etl_Tx_Dt*/
        ,Substr('s98_s_country_cde',1,3)                           /*Src_Sysname*/
        ,'s98_s_country_cde'                                       /*Src_Table*/
        
FROM p10_sa.s98_s_country_cde  p0
;



/*将不同数据插入到临时表                                                                           */
;INSERT INTO t00_country_info_agi_INS (
         country_cn_name                                           /*国家*/
        ,country_en_name                                           /*国家英文名*/
        ,country_abbr                                              /*国家缩写*/
        ,country_number                                            /*数字代码*/
        ,inter_tel_cd                                              /*国际区号*/
        ,internet_name                                             /*域名*/
        ,country_cd                                                /*国家代码*/
        ,Etl_Batch_No                                              /*作业批次号*/
        ,Etl_First_Dt                                              /*最初入库时间*/
        ,Etl_Job                                                   /*作业名称*/
        ,Etl_Proc_Dt                                               /*本次入库时间*/
        ,Etl_Tx_Dt                                                 /*作业运行时间*/
        ,Src_Sysname                                               /*来源系统*/
        ,Src_Table                                                 /*来源表*/
        
)
    SELECT
         P1.country_cn_name                                           /*国家*/
        ,P1.country_en_name                                           /*国家英文名*/
        ,P1.country_abbr                                              /*国家缩写*/
        ,P1.country_number                                            /*数字代码*/
        ,P1.inter_tel_cd                                              /*国际区号*/
        ,P1.internet_name                                             /*域名*/
        ,P1.country_cd                                                /*国家代码*/
        ,P1.Etl_Batch_No                                              /*作业批次号*/
        ,P1.Etl_First_Dt                                              /*最初入库时间*/
        ,P1.Etl_Job                                                   /*作业名称*/
        ,P1.Etl_Proc_Dt                                               /*本次入库时间*/
        ,P1.Etl_Tx_Dt                                                 /*作业运行时间*/
        ,P1.Src_Sysname                                               /*来源系统*/
        ,P1.Src_Table                                                 /*来源表*/
        
FROM t00_country_info_agi_CUR_I P1
LEFT JOIN :PDMDB.t00_country_info P2
ON    P1.country_cn_name = P2.country_cn_name
    AND P1.country_en_name = P2.country_en_name
    AND P1.country_abbr = P2.country_abbr
    AND P1.country_number = P2.country_number
    AND P1.inter_tel_cd = P2.inter_tel_cd
    AND P1.internet_name = P2.internet_name
    AND P1.country_cd = P2.country_cd
    
WHERE  P2.country_cn_name IS NULL
    OR P2.country_en_name IS NULL
    OR P2.country_abbr IS NULL
    OR P2.country_number IS NULL
    OR P2.inter_tel_cd IS NULL
    OR P2.internet_name IS NULL
    OR P2.country_cd IS NULL
    
; 
/*将新增数据插入到目标表                                                                           */
;INSERT INTO :PDMDB.t00_country_info (
         country_cn_name                                           /*国家*/
        ,country_en_name                                           /*国家英文名*/
        ,country_abbr                                              /*国家缩写*/
        ,country_number                                            /*数字代码*/
        ,inter_tel_cd                                              /*国际区号*/
        ,internet_name                                             /*域名*/
        ,country_cd                                                /*国家代码*/
        ,Etl_Batch_No                                              /*作业批次号*/
        ,Etl_First_Dt                                              /*最初入库时间*/
        ,Etl_Job                                                   /*作业名称*/
        ,Etl_Proc_Dt                                               /*本次入库时间*/
        ,Etl_Tx_Dt                                                 /*作业运行时间*/
        ,Src_Sysname                                               /*来源系统*/
        ,Src_Table                                                 /*来源表*/
        
)
SELECT
         P1.country_cn_name                                           /*国家*/
        ,P1.country_en_name                                           /*国家英文名*/
        ,P1.country_abbr                                              /*国家缩写*/
        ,P1.country_number                                            /*数字代码*/
        ,P1.inter_tel_cd                                              /*国际区号*/
        ,P1.internet_name                                             /*域名*/
        ,P1.country_cd                                                /*国家代码*/
        ,P1.Etl_Batch_No                                              /*作业批次号*/
        ,P1.Etl_First_Dt                                              /*最初入库时间*/
        ,P1.Etl_Job                                                   /*作业名称*/
        ,P1.Etl_Proc_Dt                                               /*本次入库时间*/
        ,P1.Etl_Tx_Dt                                                 /*作业运行时间*/
        ,P1.Src_Sysname                                               /*来源系统*/
        ,P1.Src_Table                                                 /*来源表*/
        
FROM t00_country_info_agi_INS P1
ON CONFLICT ( country_cd)
DO UPDATE SET
     country_cd=excluded.country_cd
    ,country_cn_name=excluded.country_cn_name
    ,country_en_name=excluded.country_en_name
    ,country_abbr=excluded.country_abbr
    ,country_number=excluded.country_number
    ,inter_tel_cd=excluded.inter_tel_cd
    ,internet_name=excluded.internet_name
    ,Etl_Batch_No=excluded.Etl_Batch_No
    ,Etl_First_Dt=excluded.Etl_First_Dt
    ,Etl_Job=excluded.Etl_Job
    ,Etl_Proc_Dt=excluded.Etl_Proc_Dt
    ,Etl_Tx_Dt=excluded.Etl_Tx_Dt
    ,Src_Sysname=excluded.Src_Sysname
    ,Src_Table=excluded.Src_Table
    

;
/*****程序结束退出                                               */
\q

